==> cms-db_v0.8.1.tar.gz: admin/recyclebin.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('recyclebin');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('desc_recyclebin') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
</head>
<body>

<h1><?php locale('desc_recyclebin') ?></h1>
<p>
	<?php locale('desc_restore') ?><br />
	<?php locale('desc_delete') ?>
</p>

<h2><?php locale('title_pages') ?></h2>
<ul class="linklist">
	<?php
	$vorhanden = false;
	if ($handle = opendir('../data/recyclebin/pages')) {
	while (false !== ($file = readdir($handle))) {
		if($file != "." && $file != "..") {
			$endung = strrchr($file, ".");
			echo '<li><a href="restorepage.php?page='.$file.'&'.SID.csrf_protection_get_html_ret().'" class="nonewtab">'.$file.'</a></li>';
			$vorhanden = true;
		}
	}
	closedir($handle);
	}
	?>
	<?php
	if ($vorhanden != true) {
		echo '<li><span class="inactive">'.locale('desc_no-pages', true).'</span></li>';
	}
	?>
</ul>
<h2><?php locale('title_files') ?></h2>
<ul class="linklist">
	<?php
	$vorhanden = false;
	if ($handle = opendir('../data/recyclebin/files')) {
	while (false !== ($file = readdir($handle))) {
		if($file != "." && $file != "..") {
			$endung = strrchr($file, ".");
			echo '<li><a href="restorefile.php?file='.$file.'&'.SID.csrf_protection_get_html_ret().'" class="nonewtab">'.$file.'</a></li>';
			$vorhanden = true;
		}
	}
	closedir($handle);
	}
	?>
	<?php
	if ($vorhanden != true) {
		echo '<li><span class="inactive">'.locale('desc_no-files', true).'</span></li>';
	}
	?>
</ul>
<h2><?php locale('title_includes') ?></h2>
<ul class="linklist">
	<?php
	$vorhanden = false;
	if ($handle = opendir('../data/recyclebin/includes')) {
	while (false !== ($file = readdir($handle))) {
		if($file != "." && $file != "..") {
			$endung = strrchr($file, ".");
			echo '<li><a href="restoreinc.php?inc='.$file.'&'.SID.csrf_protection_get_html_ret().'" class="nonewtab">'.$file.'</a></li>';
			$vorhanden = true;
		}
	}
	closedir($handle);
	}
	?>
	<?php
	if ($vorhanden != true) {
		echo '<li><span class="inactive">'.locale('desc_no-includes', true).'</span></li>';
	}
	?>
</ul>

</body>
</html>

==> cms-db_v0.9.tar.gz: admin/recyclebin.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('recyclebin');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('desc_recyclebin') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
</head>
<body>

<h1><?php locale('desc_recyclebin') ?></h1>
<p class="hint">
	<?php locale('desc_restore') ?><br />
	<?php locale('desc_delete') ?>
</p>

<h2><?php locale('title_pages') ?></h2>
<ul class="linklist">
	<?php
	$vorhanden = false;
	if ($handle = opendir('../data/recyclebin/pages')) {
	while (false !== ($file = readdir($handle))) {
		if($file != "." && $file != "..") {
			$class = (!isset($class) or $class == 'normal') ? 'alt' : 'normal';
			$endung = strrchr($file, ".");
			echo '<li class="'.$class.'"><a href="restorepage.php?page='.$file.'&'.SID.csrf_protection_get_html_ret().'" class="nonewtab">'.$file.'</a></li>';
			$vorhanden = true;
		}
	}
	closedir($handle);
	}
	?>
	<?php
	if ($vorhanden != true) {
		echo '<p class="box">'.locale('desc_no-pages', true).'</p>';
	}
	?>
</ul>
<h2><?php locale('title_files') ?></h2>
<ul class="linklist">
	<?php
	$vorhanden = false;
	if ($handle = opendir('../data/recyclebin/files')) {
	while (false !== ($file = readdir($handle))) {
		if($file != "." && $file != "..") {
			$class = (!isset($class) or $class == 'normal') ? 'alt' : 'normal';
			$endung = strrchr($file, ".");
			echo '<li class="'.$class.'"><a href="restorefile.php?file='.$file.'&'.SID.csrf_protection_get_html_ret().'" class="nonewtab">'.$file.'</a></li>';
			$vorhanden = true;
		}
	}
	closedir($handle);
	}
	?>
	<?php
	if ($vorhanden != true) {
		echo '<p class="box">'.locale('desc_no-files', true).'</p>';
	}
	?>
</ul>
<h2><?php locale('title_includes') ?></h2>
<ul class="linklist">
	<?php
	$vorhanden = false;
	if ($handle = opendir('../data/recyclebin/includes')) {
	while (false !== ($file = readdir($handle))) {
		if($file != "." && $file != "..") {
			$class = (!isset($class) or $class == 'normal') ? 'alt' : 'normal';
			$endung = strrchr($file, ".");
			echo '<li class="'.$class.'"><a href="restoreinc.php?inc='.$file.'&'.SID.csrf_protection_get_html_ret().'" class="nonewtab">'.$file.'</a></li>';
			$vorhanden = true;
		}
	}
	closedir($handle);
	}
	?>
	<?php
	if ($vorhanden != true) {
		echo '<p class="box">'.locale('desc_no-includes', true).'</p>';
	}
	?>
</ul>

</body>
</html>
